package gs.smolban.model

import java.time.Instant

/** Enumeration that describes the status of a [[Ticket]] in Smolban. Smolban
  * does not yet support custom status/workflow.
  */
sealed trait Status:
  def name: String
  def enteredAt: Instant

object Status:

  /** This ticket is new, and ready to be started. New tickets may be put into
    * progress or canceled.
    */
  case class Ready(enteredAt: Instant) extends Status:
    val name: String = "ready"

  /** This ticket is being worked on actively. In progress tickets can be
    * paused, completed, or canceled.
    */
  case class InProgress(enteredAt: Instant) extends Status:
    val name: String = "in_progress"

  /** This ticket was being worked on, but was temporarily stopped. Paused
    * tickets may be put into progress or canceled.
    */
  case class Paused(enteredAt: Instant) extends Status:
    val name: String = "paused"

  /** This ticket was driven to completion. The work is done. Once in this
    * state, the status may no longer change.
    */
  case class Complete(enteredAt: Instant) extends Status:
    val name: String = "complete"

  /** This ticket was canceled for some reason. Once in this state, the status
    * may no longer change.
    */
  case class Canceled(enteredAt: Instant) extends Status:
    val name: String = "canceled"

end Status
